summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPaul Eggert <eggert@cs.ucla.edu>2026-04-29 22:42:22 -0700
committerPaul Eggert <eggert@cs.ucla.edu>2026-04-29 22:45:51 -0700
commit4fcc8a473a19c2d80ac984c8b6ed4dda8d6679df (patch)
treee2aa12f5b7a0a963e91c4842354fca5399e1f431
parent3ce42ffd609c1004df537fa51d4ab6b2cb168c51 (diff)
; Spelling fixes.
-rw-r--r--ChangeLog.46
-rw-r--r--doc/misc/org.org2
-rw-r--r--etc/NEWS2
-rw-r--r--etc/themes/modus-themes.el2
-rw-r--r--lisp/calendar/diary-icalendar.el2
-rw-r--r--lisp/calendar/icalendar-ast.el4
-rw-r--r--lisp/calendar/icalendar-parser.el2
-rw-r--r--lisp/calendar/icalendar-recur.el20
-rw-r--r--lisp/emacs-lisp/package.el4
-rw-r--r--lisp/files.el2
-rw-r--r--lisp/net/tramp.el2
-rw-r--r--lisp/org/org-list.el2
-rw-r--r--lisp/vc/vc.el2
-rw-r--r--src/charset.c2
-rw-r--r--test/lisp/dired-tests.el6
-rw-r--r--test/lisp/files-tests.el2
-rw-r--r--test/src/fileio-tests.el2
17 files changed, 32 insertions, 32 deletions
diff --git a/ChangeLog.4 b/ChangeLog.4
index 1eb44ba7b44..0624cc5a199 100644
--- a/ChangeLog.4
+++ b/ChangeLog.4
@@ -22242,7 +22242,7 @@
2024-03-10 Andreas Schwab <schwab@linux-m68k.org>
- Avoid dependency on nonexisting target in lispref makefile
+ Avoid dependency on nonexistent target in lispref makefile
* doc/lispref/Makefile.in (auxfiles): Change target into a
variable.
@@ -83524,7 +83524,7 @@
2023-12-04 Philipp Stephani <p.stephani2@gmail.com>
- Don't claim to signal an error when deleting a nonexisting file.
+ Don't claim to signal an error when deleting a nonexistent file.
The behavior has changed in commit
1a65afb7ecc2a52127d6164bad19313440237f9d to no longer signal an error
@@ -150001,7 +150001,7 @@
2022-04-27 Lars Ingebrigtsen <larsi@gnus.org>
- Give better error message in dired-toggle-read-only on nonexisting dirs
+ Give better error message in dired-toggle-read-only on nonexistent dirs
* lisp/dired.el (dired-toggle-read-only): Refuse to edit
non-existent directories (bug#23276).
diff --git a/doc/misc/org.org b/doc/misc/org.org
index 13b9ac2026a..ab0f8a9c1a6 100644
--- a/doc/misc/org.org
+++ b/doc/misc/org.org
@@ -2252,7 +2252,7 @@ instead of letting Calc handle the formatting. A few examples:
| =exp($2)+exp($1)= | Math functions can be used |
| =$0;%.1f= | Reformat current cell to 1 decimal |
| =($3-32)*5/9= | Fahrenheit to Celsius conversion |
-| =$c/$1/$cm= | Herz to centimeter conversion, using =constants.el= |
+| =$c/$1/$cm= | Hertz to centimeter conversion using =constants.el= |
| =tan($1);Dp3s1= | Compute in degrees, precision 3, display SCI 1 |
| =sin($1);Dp3%.1e= | Same, but use ~format~ specifier for display |
| =vmean($2..$7)= | Compute column range mean, using vector function |
diff --git a/etc/NEWS b/etc/NEWS
index 971feb4edaf..fd39d965a40 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -766,7 +766,7 @@ more terminals and applications than the old capabilities, 'setf24' and
+++
** New user option 'xterm-update-cursor' to update cursor display on TTYs.
When enabled, Emacs sends Xterm escape sequences on Xterm-compatible
-terminals to update the cursor's appearacse. Emacs can update the
+terminals to update the cursor's appearance. Emacs can update the
cursor's shape and color. For example, if you use a purple bar cursor
on graphical displays then when this option is enabled Emacs will use a
purple bar cursor on compatible terminals as well. See the Info node
diff --git a/etc/themes/modus-themes.el b/etc/themes/modus-themes.el
index e61436e1cbc..8994dc68985 100644
--- a/etc/themes/modus-themes.el
+++ b/etc/themes/modus-themes.el
@@ -4564,7 +4564,7 @@ FG and BG are the main colors."
;; :underline (:style wave :color unspecified)
;;
;; I checked all the relevant faces and feel that users will not be
-;; benefitting form such a style anyway. What would be the point of a
+;; benefiting form such a style anyway. What would be the point of a
;; spell checker that cannot highlight its errors, for example?
;; Granted, we could have another kind of highlight, but I am here
;; focusing on the use of this:
diff --git a/lisp/calendar/diary-icalendar.el b/lisp/calendar/diary-icalendar.el
index 994258dedd4..bc58e7b5924 100644
--- a/lisp/calendar/diary-icalendar.el
+++ b/lisp/calendar/diary-icalendar.el
@@ -1124,7 +1124,7 @@ attendee's address matches the regexp in
(dlet ((attendee-address (ical:strip-mailto value))
(attendee-cn (when cn (string-trim cn)))
(attendee-cutype cutype)
- (attende-role role)
+ (attendee-role role)
(attendee-partstat partstat)
(attendee-rsvp rsvp))
(with-temp-buffer
diff --git a/lisp/calendar/icalendar-ast.el b/lisp/calendar/icalendar-ast.el
index fc8f23a3a27..c4faf48173f 100644
--- a/lisp/calendar/icalendar-ast.el
+++ b/lisp/calendar/icalendar-ast.el
@@ -66,7 +66,7 @@
;; Constructing nodes with these macros automatically validates them
;; with the function `icalendar-ast-node-valid-p', which signals an
-;; `icalendar-validation-error' if the node is not valid acccording to
+;; `icalendar-validation-error' if the node is not valid according to
;; RFC5545.
@@ -639,7 +639,7 @@ the following forms:
or any other expression that evaluates to a parameter node.
\(COMPONENT-TYPE CHILD [CHILD ...]) - constructs a component node of
- COMPONENT-TYPE with CHILDs as child nodes. Each CHILD should either be
+ COMPONENT-TYPE with given child nodes. Each CHILD should either be
a template for a property (as above), a template for a
sub-component (of the same form), or any other expression that
evaluates to an iCalendar syntax node.
diff --git a/lisp/calendar/icalendar-parser.el b/lisp/calendar/icalendar-parser.el
index 86dbcff1ce3..93293f19cbf 100644
--- a/lisp/calendar/icalendar-parser.el
+++ b/lisp/calendar/icalendar-parser.el
@@ -112,7 +112,7 @@ errors instead of silently accepting such data."
;; `ical:unfold-region'. `ical:fold-region' will fold content lines
;; using line breaks appropriate to the buffer's coding system.
;;
-;; All the parsing-related code belows assumes that lines have
+;; All the parsing-related code below assumes that lines have
;; already been unfolded if necessary.
(defcustom ical:pre-unfolding-hook nil
"Hook run before unfolding iCalendar data.
diff --git a/lisp/calendar/icalendar-recur.el b/lisp/calendar/icalendar-recur.el
index cf751c83184..fcebbc9c6f0 100644
--- a/lisp/calendar/icalendar-recur.el
+++ b/lisp/calendar/icalendar-recur.el
@@ -896,7 +896,7 @@ BYHOUR=... clause; see `icalendar-recur' for the possible values."
:hour h :minute 0 :second 0
:tz vtimezone))
(high (ical:date/time-add low :hour 1 vtimezone)))
- (ignore-errors ; do not generate subintervals for nonexisting times
+ (ignore-errors ; do not generate subintervals for nonexistent times
(when (ical:date/time< low curr-dt)
(setq low curr-dt))
(when (ical:date/time< interval-end high)
@@ -932,7 +932,7 @@ BYMINUTE=... clause; see `icalendar-recur' for the possible values."
(let* ((low (ical:date-time-variant curr-dt :minute m :second 0
:tz vtimezone))
(high (ical:date/time-add low :minute 1 vtimezone)))
- (ignore-errors ; do not generate subintervals for nonexisting times
+ (ignore-errors ; do not generate subintervals for nonexistent times
;; Clip the subinterval, as above
(when (ical:date/time< low interval-start)
(setq low curr-dt))
@@ -1703,7 +1703,7 @@ The check is performed with `icalendar-time<='."
(ical:time<= dt (encode-time end)))))
;; DRAGONS DRAGONS DRAGONS
-(defun icr:tz-observance-on (dt vtimezone &optional update nonexisting)
+(defun icr:tz-observance-on (dt vtimezone &optional update nonexistent)
"Return the time zone observance in effect on DT in VTIMEZONE.
If there is such an observance, the returned value is a list (OBSERVANCE
@@ -1727,7 +1727,7 @@ If UPDATE is non-nil, the observance found will be used to update the
offset value in DT (as a side effect) before returning the observance
and onset.
-If UPDATE is non-nil, NONEXISTING specifies how to handle clock times
+If UPDATE is non-nil, NONEXISTENT specifies how to handle clock times
that do not exist in the observance (see
`icalendar-recur-tz-nonexistent-date-time-p'). The keyword `:error'
means to signal an \\='icalendar-tz-nonexistent-time error, without
@@ -1735,13 +1735,13 @@ modifying any of the fields in DT. Otherwise, the default is to
interpret DT using the offset from UTC before the onset of the found
observance, and then reset the clock time in DT to the corresponding
existing time after the onset of the observance. For example, the
-nonexisting time 2:30AM in Standard time on the day of the switch to
+nonexistent time 2:30AM in Standard time on the day of the switch to
Daylight time in the US Eastern time zone will be reset to 3:30AM
Eastern Daylight time.
If DT is a Lisp timestamp, it represents an absolute time and
comparisons with the onsets in VTIMEZONE are performed with absolute
-times. UPDATE and NONEXISTING have no meaning in this case and are
+times. UPDATE and NONEXISTENT have no meaning in this case and are
ignored."
(ical:with-component vtimezone
((ical:standard :all stds)
@@ -1916,7 +1916,7 @@ ignored."
(when (and update given-clock-time nearest-observance updated)
;; signal an error when `dt' does not exist if requested, so the
;; nonexistence can be handled further up the stack:
- (when (and (eq :error nonexisting)
+ (when (and (eq :error nonexistent)
(not (ical:date-time-locally-simultaneous-p dt updated)))
(signal 'ical:tz-nonexistent-time
(list
@@ -1984,7 +1984,7 @@ decoded directly into this UTC offset, and its dst slot is set to -1."
:dst (if observance (ical:daylight-component-p observance)
-1))))
-(defun icr:tz-set-zone (dt vtimezone &optional nonexisting)
+(defun icr:tz-set-zone (dt vtimezone &optional nonexistent)
"Set the time zone offset and dst flag in DT based on VTIMEZONE.
DT should be an `icalendar-date-time' and VTIMEZONE should be an
@@ -1999,7 +1999,7 @@ where a different time zone observance may be in effect in the original
date-time. It cannot be used to re-decode a fixed point in time into a
different time zone; for that, see `icalendar-recur-tz-decode-time'.
-If given, NONEXISTING is a keyword that specifies what to do if DT
+If given, NONEXISTENT is a keyword that specifies what to do if DT
represents a clock time that does not exist according to the relevant
observance in VTIMEZONE. The value :error means to signal an
\\='icalendar-tz-nonexistent-time error, and nil means to reset the
@@ -2030,7 +2030,7 @@ clock time in DT to an existing one; see
;; This updates the relevant slots in dt as a side effect:
;; TODO: if no observance is found, is it ever sensible to signal an error,
;; instead of just leaving the zone slot unset?
- (icr:tz-observance-on dt vtimezone t nonexisting)))
+ (icr:tz-observance-on dt vtimezone t nonexistent)))
dt)
(defun icr:tz-set-zones-in (vtimezones node)
diff --git a/lisp/emacs-lisp/package.el b/lisp/emacs-lisp/package.el
index 93fdc81164f..e1486418876 100644
--- a/lisp/emacs-lisp/package.el
+++ b/lisp/emacs-lisp/package.el
@@ -4593,7 +4593,7 @@ SUG should be of the form as described in `package--suggestion-applies-p'."
(with-current-buffer buf
(funcall-interactively (or (cadddr sug) (car sug)))))))))
-(defun package--autosugest-prompt (packages)
+(defun package--autosuggest-prompt (packages)
"Query the user whether to install PACKAGES or not.
PACKAGES is a list of package suggestions in the form described in
`package--suggestion-applies-p'. The function returns a non-nil value
@@ -4676,7 +4676,7 @@ The optional argument CANDIDATES may be a list of package suggestions
in the form described in `package--suggestion-applies-p'. If omitted
or nil, the list of candidates will be computed from the database."
(interactive)
- (package--autosugest-prompt
+ (package--autosuggest-prompt
(or candidates
(package--autosuggest-find-candidates)
(user-error "No package suggestions found"))))
diff --git a/lisp/files.el b/lisp/files.el
index d555fab7323..9b1fc09fcfa 100644
--- a/lisp/files.el
+++ b/lisp/files.el
@@ -7989,7 +7989,7 @@ RULE has the form (MATCH EXPANSION...).
MATCH is a regular expression that should match a file name which might
have a sibling. It can contain sub-expressions that will be used in
-EXPANSIONs as \\N and \\& replacements.
+each EXPANSION as \\N and \\& replacements.
Each EXPANSION is a string that matches names of files that are to be
considered siblings of a file whose name matches MATCH. For instance,
diff --git a/lisp/net/tramp.el b/lisp/net/tramp.el
index 553b76bd044..6219d097f4f 100644
--- a/lisp/net/tramp.el
+++ b/lisp/net/tramp.el
@@ -2428,7 +2428,7 @@ arguments to pass to the OPERATION."
An entry has the form `(OPERATION . ARG-TYPE)'. ARG-TYPE can be the
symbol
-- `file': the first argument of OERATION is the remote file name to be
+- `file': the first argument of OPERATION is the remote file name to be
checked.
- `default-directory': `default-directory' is the remote file name to be
checked.
diff --git a/lisp/org/org-list.el b/lisp/org/org-list.el
index 687098c1c14..c13ec193ffe 100644
--- a/lisp/org/org-list.el
+++ b/lisp/org/org-list.el
@@ -1860,7 +1860,7 @@ Initial position of cursor is restored after the changes."
;; Shift the indentation between END and BEG by DELTA.
;; Start from the line before END.
;; Take care not to shift to or before IND, which is the
- ;; containg list item indentation. (otherwise, we are going
+ ;; containing list item indentation. (otherwise, we are going
;; to break the list structure)
(lambda (end beg delta ind)
(goto-char end)
diff --git a/lisp/vc/vc.el b/lisp/vc/vc.el
index 0b64ea93efb..3d8c4bf4f1c 100644
--- a/lisp/vc/vc.el
+++ b/lisp/vc/vc.el
@@ -294,7 +294,7 @@
;; RCS and CVS, and is otherwise silently ignored.
;;
;; If the backend supports async checkins and `vc-async-checkin' is
-;; non-nil, the implementation should start an asychronous process to
+;; non-nil, the implementation should start an asynchronous process to
;; commit the changes, and return a cons whose car is `async' and
;; whose cdr is that process object.
;;
diff --git a/src/charset.c b/src/charset.c
index e4d95653e66..9ff3191b7e3 100644
--- a/src/charset.c
+++ b/src/charset.c
@@ -2357,7 +2357,7 @@ init_charset_once (void)
PDUMPER_REMEMBER_SCALAR (charset_ksc5601);
}
-/* Intitial value for charset_table_size. As of October 2025, the
+/* Initial value for charset_table_size. As of October 2025, the
charset table uses 179 entries. charset_table grows if needed and
we only dump the used entries; so getting the initial value right
is not overly important. */
diff --git a/test/lisp/files-tests.el b/test/lisp/files-tests.el
index 1dcd5161ee9..55011cd461a 100644
--- a/test/lisp/files-tests.el
+++ b/test/lisp/files-tests.el
@@ -1080,7 +1080,7 @@ unquoted file names."
;; handler prefix has been removed.
(nospecial-dir (string-remove-prefix "/:" nospecial-dir))
;; Since different `ls' programs can produce different
- ;; messages for the nonexisting file error, we make a sample
+ ;; messages for the nonexistent file error, we make a sample
;; message to use for comparing the expected message with
;; the string in the error buffer.
(ls-err (lambda (fn)
diff --git a/test/src/fileio-tests.el b/test/src/fileio-tests.el
index 6d687b85033..b130f37620a 100644
--- a/test/src/fileio-tests.el
+++ b/test/src/fileio-tests.el
@@ -216,7 +216,7 @@ Also check that an encoding error can appear in a symlink."
(put 'fileio-tests--identity-expand-handler 'operations '(expand-file-name))
(ert-deftest fileio--file-name-case-insensitive-p ()
- ;; Check that we at least don't crash if given nonexisting files
+ ;; Check that we at least don't crash if given nonexistent files
;; without a directory (bug#56443).
;; Use an identity file-name handler, as if called by `ffap'.
diff --git a/test/lisp/dired-tests.el b/test/lisp/dired-tests.el
index b2e0f257a15..f77d56637fd 100644
--- a/test/lisp/dired-tests.el
+++ b/test/lisp/dired-tests.el
@@ -728,9 +728,9 @@ The current directory at call time should not affect the result (Bug#50630)."
(delete-directory dir t)))
(ert-deftest dired-test-ls-error-message () ; bug#80499
- "Test invoking `dired' on a nonexisting file.
+ "Test invoking `dired' on a nonexistent file.
A buffer should pop up containing the error emitted by ls. The buffer
-visiting the nonexisting file should killed before `dired' returns,
+visiting the nonexistent file should killed before `dired' returns,
hence another buffer should be returned."
(let* ((dir (ert-resource-file (file-name-as-directory "empty-dir")))
(name (concat dir "bla"))
@@ -755,7 +755,7 @@ hence another buffer should be returned."
(null ls-lisp-use-insert-directory-program))
(let ((errbuf (get-buffer "*ls error*"))
;; Since different `ls' programs can produce different
;; messages for the nonexisting file error, we make a sample
;; message to use for comparing the expected message with
;; the string in the error buffer.
(ls-err (lambda (fn)
@@ -755,7 +755,7 @@ hence another buffer should be returned."
(let ((errbuf (get-buffer "*ls error*"))
;; Since different `ls' programs can produce different
- ;; messages for the nonexisting file error, we make a sample
+ ;; messages for the nonexistent file error, we make a sample
;; message to use for comparing the expected message with
;; the string in the error buffer.